@@ -1,25 +1,20 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# Copyright (c) Mito.
-# Distributed under the terms of the Modified BSD License.
-
-from typing import TYPE_CHECKING, Any, Dict, Collection, List, Optional, Tuple, Union
+# Copyright (c) Saga Inc.
+# Distributed under the terms of the GPL License.
+from typing import (Any, Collection, Dict, List, Optional,
+                    Tuple, Union)
 
 import pandas as pd
+from mitosheet.code_chunks.step_performers.import_steps.simple_import_code_chunk import generate_read_csv_code
 from mitosheet.errors import get_recent_traceback_as_list
-from mitosheet.mito_analytics import log
+from mitosheet.telemetry.telemetry_utils import log
 from mitosheet.preprocessing.preprocess_step_performer import \
     PreprocessStepPerformer
 from mitosheet.step_performers.import_steps.simple_import import (
-    generate_read_csv_code, get_valid_dataframe_names,
-    read_csv_get_delimeter_and_encoding)
-
-    # To avoid circular imports
-if TYPE_CHECKING:
-    from mitosheet.steps_manager import StepsManager
-else: 
-    StepsManager = Any
+    get_valid_dataframe_names, read_csv_get_delimiter_and_encoding)
+from mitosheet.types import StepsManagerType
 
 
 class ReadFilePathsPreprocessStepPerformer(PreprocessStepPerformer):
@@ -51,7 +46,7 @@ class ReadFilePathsPreprocessStepPerformer(PreprocessStepPerformer):
                 # If it is a string, we try and read it in as a dataframe
                 try:
                     # We use the simple import 
-                    df, delimeter, encoding = read_csv_get_delimeter_and_encoding(arg)
+                    df, delimeter, encoding = read_csv_get_delimiter_and_encoding(arg)
 
                     df_args.append(
                         df
@@ -63,20 +58,20 @@ class ReadFilePathsPreprocessStepPerformer(PreprocessStepPerformer):
                     # If this pd.read_csv fails, then we report this error to the user
                     # as a failed mitosheet call
                     error_message = f'Invalid argument passed to sheet: {arg}. This path could not be read with a pd.read_csv call. Please pass in the parsed dataframe directly.'
-                    log('mitosheet_sheet_call_failed', {'error': error_message, 'error_traceback': get_recent_traceback_as_list()})
+                    log('mitosheet_sheet_call_failed', failed=True)
                     raise ValueError(error_message)
             else:
                 error_message = f'Invalid argument passed to sheet: {arg}. Please pass all dataframes or paths to CSV files.'
-                log('mitosheet_sheet_call_failed', {'error': error_message})
+                log('mitosheet_sheet_call_failed', {'error': error_message}, failed=True)
                 raise ValueError(error_message)
                 
         return df_args, {
             'delimeters': delimeters,
-            'encodings': encodings
+            'encodings': encodings,
         }
 
     @classmethod
-    def transpile(cls, steps_manager: StepsManager, execution_data: Optional[Dict[str, Any]]) -> List[str]:
+    def transpile(cls, steps_manager: StepsManagerType, execution_data: Optional[Dict[str, Any]]) -> List[str]:
         """
         Transpiles the reading in of passed file paths to dataframe names, 
         with a simple pd.read_csv call.
@@ -103,7 +98,7 @@ class ReadFilePathsPreprocessStepPerformer(PreprocessStepPerformer):
                 num_strs += 1
 
                 read_csv_code = generate_read_csv_code(
-                    arg, df_name, delimeters[arg_index], encodings[arg_index]
+                    arg, df_name, delimeters[arg_index], encodings[arg_index], None, None, None
                 )
 
                 code.append(
