@@ -35,7 +35,8 @@ from mitosheet.step_performers import (
     ExcelRangeImportStepPerformer,
     ExportToFileStepPerformer,
     ResetIndexStepPerformer,
-    SnowflakeImportStepPerformer
+    SnowflakeImportStepPerformer,
+    AITransformationStepPerformer
 )
 from mitosheet.step_performers.import_steps.dataframe_import import DataframeImportStepPerformer
 from mitosheet.step_performers.delete_row import DeleteRowStepPerformer
@@ -284,7 +285,7 @@ def test_params_static():
 
     check_step(
         ExcelRangeImportStepPerformer,
-        1,
+        2,
         'excel_range_import'
     )
 
@@ -300,4 +301,10 @@ def test_params_static():
         'snowflake_import'
     )
 
-    assert len(STEP_PERFORMERS) == 36
\ No newline at end of file
+    check_step(
+        AITransformationStepPerformer,
+        1,
+        'ai_transformation'
+    )
+
+    assert len(STEP_PERFORMERS) == 37
\ No newline at end of file
